Module error

Module error 

Structs

UnboundError
Error returned when the value of a crate::Secret is accessed before it has been bound.

Enums

BindError
Errors that can occur while binding a secret to its value.
SourceError
Errors produced by a crate::Source during secret retrieval.
SourceRegisterError
Errors returned by crate::SourceRegistry::register.
UrnParseError
Errors that can occur when parsing a secret URN string.