Trait Source 

pub trait Source: Send + Sync {
    // Required method
    fn get(&self, name: &str) -> Result<Vec<u8>, SourceError>;
}
A source from which secret values can be retrieved.

Implementations are responsible for looking up a secret by name and returning its raw bytes. Case sensitivity of name is source-specific.

Required Methods

fn get(&self, name: &str) -> Result<Vec<u8>, SourceError>

Retrieve the raw bytes for the secret identified by name.

Implementors